@@ -19,7 +19,7 @@
  *
  *  You should have received a copy of the GNU Library General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -135,7 +135,8 @@ get_dependant_plugins (PeasGtkPluginManagerView *view,
     {
       PeasPluginInfo *plugin = (PeasPluginInfo *) plugins->data;
 
-      if (!peas_plugin_info_is_loaded (plugin))
+      if (peas_plugin_info_is_hidden (plugin) ||
+          !peas_plugin_info_is_loaded (plugin))
         continue;
 
       /* Don't add builtin plugins if they are not shown */
@@ -781,6 +782,8 @@ peas_gtk_plugin_manager_view_class_init (PeasGtkPluginManagerViewClass *klass)
    * PeasGtkPluginManagerView:show-builtin:
    *
    * If builtin plugins should be shown.
+   *
+   * Deprecated: 1.2: Use hidden plugins instead.
    */
   g_object_class_install_property (object_class,
                                    PROP_SHOW_BUILTIN,
@@ -799,7 +802,7 @@ peas_gtk_plugin_manager_view_class_init (PeasGtkPluginManagerViewClass *klass)
    * @view: A #PeasGtkPluginManagerView.
    * @menu: A #GtkMenu.
    *
-   * The populate-popup signal is emitted before showing the context
+   * The ::populate-popup signal is emitted before showing the context
    * menu of the view. If you need to add items to the context menu,
    * connect to this signal and add your menuitems to the @menu.
    */
@@ -844,7 +847,7 @@ peas_gtk_plugin_manager_view_new (PeasEngine *engine)
  *
  * Sets if builtin plugins should be shown.
  *
- * Deprecated: 1.2. Use hidden plugins instead.
+ * Deprecated: 1.2: Use hidden plugins instead.
  */
 void
 peas_gtk_plugin_manager_view_set_show_builtin (PeasGtkPluginManagerView *view,
@@ -906,7 +909,7 @@ peas_gtk_plugin_manager_view_set_show_builtin (PeasGtkPluginManagerView *view,
  *
  * Returns: if builtin plugins should be shown.
  *
- * Deprecated: 1.2. Use hidden plugins instead.
+ * Deprecated: 1.2: Use hidden plugins instead.
  */
 gboolean
 peas_gtk_plugin_manager_view_get_show_builtin (PeasGtkPluginManagerView *view)
