@@ -16,7 +16,7 @@
  *
  *  You should have received a copy of the GNU Library General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -26,8 +26,8 @@
 #include <string.h>
 
 #include <girepository.h>
-#include <gjs/gi/arg.h>
-#include <gjs/gi/value.h>
+#include <gi/arg.h>
+#include <gi/value.h>
 
 #include <libpeas/peas-introspection.h>
 #include <libpeas/peas-extension-subclasses.h>
