@@ -16,7 +16,7 @@
  *
  *  You should have received a copy of the GNU Library General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -64,6 +64,19 @@ test_extension_gjs_plugin_info (PeasEngine *engine)
   g_object_unref (extension);
 }
 
+static void
+test_extension_gjs_nonexistent (PeasEngine *engine)
+{
+  PeasPluginInfo *info;
+
+  testing_util_push_log_hook ("*Failed to open *extension-gjs-nonexistent.js*");
+  testing_util_push_log_hook ("Error loading plugin 'extension-gjs-nonexistent'");
+
+  info = peas_engine_get_plugin_info (engine, "extension-gjs-nonexistent");
+
+  g_assert (!peas_engine_load_plugin (engine, info));
+}
+
 int
 main (int   argc,
       char *argv[])
@@ -75,6 +88,7 @@ main (int   argc,
   EXTENSION_TESTS (gjs);
 
   EXTENSION_TEST (gjs, "plugin-info", plugin_info);
+  EXTENSION_TEST (gjs, "nonexistent", nonexistent);
 
   return testing_run_tests ();
 }
