@@ -16,7 +16,7 @@
  *
  *  You should have received a copy of the GNU Library General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifndef __TESTING_EXTENSION_H__
@@ -58,12 +58,6 @@ void testing_extension_properties_read_only_      (PeasEngine *engine);
 void testing_extension_properties_write_only_     (PeasEngine *engine);
 void testing_extension_properties_readwrite_      (PeasEngine *engine);
 
-#define _EXTENSION_TESTS_INIT(loader) \
-  testing_init (); \
-  peas_engine_enable_loader (peas_engine_get_default (), #loader); \
-  g_object_unref (peas_engine_get_default ()); \
-  testing_extension_set_plugin_ ("extension-" #loader)
-
 #define _EXTENSION_TEST(loader, path, ftest) \
   g_test_add ("/extension/" #loader "/" path, TestingExtensionFixture_, \
               (gpointer) testing_extension_##ftest##_, \
@@ -71,8 +65,13 @@ void testing_extension_properties_readwrite_      (PeasEngine *engine);
               testing_extension_test_runner_, \
               testing_extension_test_teardown_)
 
-#define EXTENSION_TESTS(loader) \
-  _EXTENSION_TESTS_INIT(loader); \
+/* This also tests that loaders are loaded lazily */
+#define EXTENSION_TESTS_INIT(loader) \
+  testing_init (); \
+  peas_engine_enable_loader (peas_engine_get_default (), #loader); \
+  g_assert (g_type_from_name ("PeasPluginLoader") == G_TYPE_INVALID); \
+  g_object_unref (peas_engine_get_default ()); \
+  testing_extension_set_plugin_ ("extension-" #loader); \
 \
   _EXTENSION_TEST (loader, "garbage-collect", garbage_collect); \
 \
@@ -82,17 +81,24 @@ void testing_extension_properties_readwrite_      (PeasEngine *engine);
   _EXTENSION_TEST (loader, "create-valid", create_valid); \
   _EXTENSION_TEST (loader, "create-invalid", create_invalid); \
 \
-  _EXTENSION_TEST (loader, "reload", reload); \
-\
+  _EXTENSION_TEST (loader, "reload", reload)
+
+#define EXTENSION_TESTS_CALLABLE(loader) \
   _EXTENSION_TEST (loader, "call-no-args", call_no_args); \
   _EXTENSION_TEST (loader, "call-with-return", call_with_return); \
   _EXTENSION_TEST (loader, "call-single-arg", call_single_arg); \
-  _EXTENSION_TEST (loader, "call-multi-args", call_multi_args); \
-\
+  _EXTENSION_TEST (loader, "call-multi-args", call_multi_args)
+
+#define EXTENSION_TESTS_PROPERTIES(loader) \
   _EXTENSION_TEST (loader, "properties-construct-only", properties_construct_only); \
   _EXTENSION_TEST (loader, "properties-read-only", properties_read_only); \
   _EXTENSION_TEST (loader, "properties-write-only", properties_write_only); \
-  _EXTENSION_TEST (loader, "properties-readwrite", properties_readwrite);
+  _EXTENSION_TEST (loader, "properties-readwrite", properties_readwrite)
+
+#define EXTENSION_TESTS(loader) \
+  EXTENSION_TESTS_INIT (loader); \
+  EXTENSION_TESTS_CALLABLE (loader); \
+  EXTENSION_TESTS_PROPERTIES (loader)
 
 /* This macro is there to add loader-specific tests. */
 #define EXTENSION_TEST(loader, path, func) \
